@@ -463,6 +463,9 @@ function insert_product($frm, $HTTP_POST_FILES) {
 	/* add the product into the products table */
 	if ($frm[extended_description] == "")
 		$frm[extended_description] = $frm[description];
+	while (list($key, $val) = each($frm)){
+		if (is_string($val)) $frm[$key] = addslashes($val);
+	}
 	$qid = db_query("
 	INSERT INTO products (id, name, brand_id, price, iva_id, discount, discqty, weight, on_special, description, extended_description, imagetype, imagewidth, imageheight, thumbwidth, thumbheight)
 	VALUES ('$frm[product_id]', '$frm[name]', '$frm[brand_id]', '$frm[price]', '$frm[iva_id]', '$frm[discount]', '$frm[discqty]', '$frm[weight]', '$frm[on_special]', '$frm[description]', '$frm[extended_description]', '$type', '$size[0]', '$size[1]', '$thumbsize[0]', '$thumbsize[1]')
@@ -515,55 +518,60 @@ foreach($HTTP_POST_FILES['userfile'] as $k => $v) {
 			$upload_name = $upload_path.string_cleanup($frm[product_id]);
 			$old_upload_name_thumb = $old_upload_name.".thumb.jpg";
 			$upload_name_thumb = $upload_name.".thumb.jpg";
-			system ("mv $old_upload_name_thumb $upload_name_thumb", $result);
+			rename ($old_upload_name_thumb, $upload_name_thumb);
 			$old_upload_name .= ".".$frm["old_imagetype"];
 			$upload_name .= ".".$frm["old_imagetype"];
-			system ("mv $old_upload_name $upload_name", $result);
+			rename ($old_upload_name, $upload_name);
 		}
 	} else {
 		$size = getimagesize ($HTTP_POST_FILES['userfile']['tmp_name']);
 		switch ($size[2]) {
 			case 1 :
-				$type = "gif";
+				$newtype = "gif";
 				$convert = "giftopnm";
 				break;
 			case 2 :
-				$type = "jpg";
+				$newtype = "jpg";
 				$convert = "djpeg";
 				break;
 			case 3 :
-				$type = "png";
+				$newtype = "png";
 				$convert = "pngtopnm";
 				break;
 			default:
-				$type = "";
+				$newtype = "";
 				echo "<div class=warning>" . $unsupported_image_type . "</div>";
 		}
-		if ($type != "") {
+		if ($newtype != "") {
 			$upload_path = $CFG->productsdir;
 			$upload_name = $upload_path.string_cleanup($frm[product_id]);
 			$upload_thumb_name = $upload_name.".thumb.jpg";
-			$upload_name .= ".".$type;
+			$upload_name .= ".".$newtype;
+			$type = $newtype;
+			$imagewidth = $size[0];
+			$imageheight = $size[1];
 			system("$CFG->pnmpath/$convert ".$HTTP_POST_FILES['userfile']['tmp_name']." | ".
 				"$CFG->pnmpath/pnmscale -xysize 100 80 | ".
 				"$CFG->pnmpath/cjpeg -optimize -progressive -quality 85 > ".
 				$upload_thumb_name, $result);
 			$thumbsize = getimagesize ($upload_thumb_name);
+			$thumbwidth = $thumbsize[0];
+			$thumbheight = $thumbsize[1];
 			if (!copy($HTTP_POST_FILES['userfile']['tmp_name'],$upload_name)) {
 				echo "<div class=warning>" . $image_upload_failed . "</div>";
 			} else {
 				system ("chmod 644 $upload_name", $result);
 			}
-		}
-		if ($frm["old_imagetype"] != "" && ($frm[old_product_id] != $frm[product_id] || $frm["old_imagetype"] != $type)) {
-			$upload_path = $CFG->productsdir;
-			$old_upload_name = $upload_path.string_cleanup($frm[old_product_id]);
-			if ($frm[old_product_id] != $frm[product_id]) {
-				$old_upload_name_thumb = $old_upload_name.".thumb.jpg";
-				system ("rm -f $old_upload_name_thumb", $result);
+			if ($frm["old_imagetype"] != "" && ($frm[old_product_id] != $frm[product_id] || $frm["old_imagetype"] != $newtype)) {
+				$upload_path = $CFG->productsdir;
+				$old_upload_name = $upload_path.string_cleanup($frm[old_product_id]);
+				if ($frm[old_product_id] != $frm[product_id]) {
+					$old_upload_name_thumb = $old_upload_name.".thumb.jpg";
+					system ("rm -f $old_upload_name_thumb", $result);
+				}
+				$old_upload_name .= ".".$frm["old_imagetype"];
+				system ("rm -f $old_upload_name", $result);
 			}
-			$old_upload_name .= ".".$frm["old_imagetype"];
-			system ("rm -f $old_upload_name", $result);
 		}
 	}
 
@@ -572,6 +580,9 @@ foreach($HTTP_POST_FILES['userfile'] as $k => $v) {
 	/* update the products table with the new information */
 	if ($frm[extended_description] == "")
 		$frm[extended_description] = $frm[description];
+	while (list($key, $val) = each($frm)){
+		if (is_string($val)) $frm[$key] = addslashes($val);
+	}
 	$qid = db_query("
 	UPDATE products SET
 	 	 id = '$frm[product_id]'
@@ -586,10 +597,10 @@ foreach($HTTP_POST_FILES['userfile'] as $k => $v) {
 		,description = '$frm[description]'
 		,extended_description = '$frm[extended_description]'
 		,imagetype = '$type'
-		,imagewidth = '$size[0]'
-		,imageheight = '$size[1]'
-		,thumbwidth = '$thumbsize[0]'
-		,thumbheight = '$thumbsize[1]'
+		,imagewidth = '$imagewidth'
+		,imageheight = '$imageheight'
+		,thumbwidth = '$thumbwidth'
+		,thumbheight = '$thumbheight'
 	WHERE id = '$frm[old_product_id]'
 	");
 
@@ -688,6 +699,8 @@ function import_products($HTTP_POST_FILES) {
 	$fcontents = file ($HTTP_POST_FILES['userfile']['tmp_name']);
 	/* Traverse the file */
 	while (list ($line_num, $line) = each ($fcontents)) {
+		// Microsoft Stupidity Suppression
+		$line = ereg_replace(chr(13), "", $line);
 		$fldarr = split("\t",ereg_replace("\n$","",$line));
 //echo "<b>" . $line_num . "</b>:" . $line . "<br>";
 		/* Stripping dangerous characters from field */
@@ -852,9 +865,6 @@ function import_images($HTTP_POST_FILES) {
 	system ("mkdir " . $tmpdir, $result);
 	system ("unzip -qq ".$HTTP_POST_FILES['userfile']['tmp_name']." -d " . $tmpdir, $result);
 	system ("gzip -dc ".$HTTP_POST_FILES['userfile']['tmp_name']." | tar xf - -C " . $tmpdir, $result);
-//while (list ($line_num, $line) = each ($result)) {
-//echo $line . "<br>";
-//}
 	// Let's manage all files in the tempdir
 	$handle=opendir($tmpdir);
 //echo "Directory handle: $handle\n";
