@@ -199,7 +199,7 @@ function find_products($stringtsf_stripped, $case_sensitive=0, $concatenation) {
 	$l_array_of_elements = explode(" ",$stringtsf_stripped);
 	foreach($l_array_of_elements as $l_search_element){
 		if ($l_search_element != "") 
-			$l_search_condition.="(name $l_matches_regex '$l_search_element' OR description $l_matches_regex '$l_search_element') $concatenation ";
+			$l_search_condition.="(name $l_matches_regex '$l_search_element' OR description $l_matches_regex '$l_search_element' OR extended_description $l_matches_regex '$l_search_element') $concatenation ";
 	}
 
 	if ($concatenation == "OR") {
@@ -289,7 +289,7 @@ function advanced_find_products($frm) {
 		$desc_l_search_condition = "(";
 		foreach($l_array_of_elements as $l_search_element) {
 			if ($l_search_element != "") 
-				$desc_l_search_condition.="(description $desc_l_matches_regex '$l_search_element') $desc_concatenation ";
+				$desc_l_search_condition.="(description $desc_l_matches_regex '$l_search_element' OR extended_description $desc_l_matches_regex '$l_search_element') $desc_concatenation ";
 		}
 
 		if ($desc_concatenation == "OR") {
