@@ -171,7 +171,7 @@ function reset_user_password($username) {
 	/* load up the user record */
 	$qid = db_query("SELECT username, priv, firstname, lastname, email FROM users WHERE username = '$username'");
 	$user = db_fetch_object($qid, 0);
-	if ($user->priv == "admin" || !($SESSION["user"]["priv"] == "admin")) {
+	if ($user->priv == "admin" || $SESSION["user"]["priv"] != "admin") {
 		return 1;
 	}
 
@@ -266,8 +266,8 @@ function save_orderinfo(&$frm) {
 	$order->city = $frm["city"];
 	$order->state = $frm["state"];
 	$order->zip_code = $frm["zip_code"];
-	$order->creditcard = $frm["creditcard"];
-	$order->expiry = $frm["expiry"];
+//	$order->creditcard = $frm["creditcard"];
+//	$order->expiry = $frm["expiry"];
 	$order->comments = $frm["comments"];
 	
 	$SESSION["orderinfo"] = $order;
@@ -686,8 +686,10 @@ function validate_contact($contact, &$errors, &$msg) {
 	} else {
 		$contact = ereg_replace (" ", "", $contact);
 		$contact = ereg_replace ("\+", "", $contact);
+		$contact = ereg_replace ("\-", "", $contact);
 		$contact = ereg_replace ("\(", "", $contact);
 		$contact = ereg_replace ("\)", "", $contact);
+		$contact = ereg_replace ("\/", "", $contact);
 		eregi ("[0-9]+", $contact, $matched_contact);
 		if ($contact != $matched_contact[0]) {
 			$errors->contact = true;
@@ -710,8 +712,10 @@ function validate_fax($fax, &$errors, &$msg) {
 	} else {
 		$fax = ereg_replace (" ", "", $fax);
 		$fax = ereg_replace ("\+", "", $fax);
+		$fax = ereg_replace ("\-", "", $fax);
 		$fax = ereg_replace ("\(", "", $fax);
 		$fax = ereg_replace ("\)", "", $fax);
+		$fax = ereg_replace ("\/", "", $fax);
 		eregi ("[0-9]+", $fax, $matched_fax);
 		if ($fax != $matched_fax[0]) {
 			$errors->fax = true;
@@ -734,8 +738,10 @@ function validate_mobilephone($mobilephone, &$errors, &$msg) {
 	} else {
 		$mobilephone = ereg_replace (" ", "", $mobilephone);
 		$mobilephone = ereg_replace ("\+", "", $mobilephone);
+		$mobilephone = ereg_replace ("\-", "", $mobilephone);
 		$mobilephone = ereg_replace ("\(", "", $mobilephone);
 		$mobilephone = ereg_replace ("\)", "", $mobilephone);
+		$mobilephone = ereg_replace ("\/", "", $mobilephone);
 		eregi ("[0-9]+", $mobilephone, $matched_mobilephone);
 		if ($mobilephone != $matched_mobilephone[0]) {
 			$errors->mobilephone = true;
