@@ -388,7 +388,7 @@ $customer_too_long = "Campo Cliente troppo lungo: " . $appoggio . " caratteri ma
 $empty_contact = "Non &egrave; stato specificato un recapito telefonico";
 $contact_too_long = "Recapito telefonico troppo lungo: ".$SESSION["phone_length"]." caratteri max";
 $contact_too_short = "Recapito telefonico troppo corto: ".$SESSION["phone_length_min"]." caratteri min";
-$not_valid_contact = "Recapito telefonico non valido";
+$not_valid_contact = "Recapito telefonico non valido; sono ammessi solo spazi, cifre e i seguenti caratteri: +-()/";
 $comments_too_long = "Commenti troppo lunghi: ".$SESSION["comments_length"]." caratteri max";
 
 ////////////////////////////////////////////////////////////
