@@ -385,7 +385,7 @@ $customer_too_long = "Customer too much long: " . $appoggio . " characters max";
 $empty_contact = "You did not specify a Phone to contact you";
 $contact_too_long = "Contact Phone number too much long: ".$SESSION["phone_length"]." characters max";
 $contact_too_short = "Contact Phone number too much short: ".$SESSION["phone_length_min"]." characters min";
-$not_valid_contact = "Contact Phone number not valid";
+$not_valid_contact = "Contact Phone number not valid; only cyphers, spaces, +-()/ are allowed characters";
 $comments_too_long = "Comments too much long: ".$SESSION["comments_length"]." characters max";
 
 ////////////////////////////////////////////////////////////
